/*
 * Copyright (c) 2017-2020, Lawrence Livermore National Security, LLC and
 * other Axom Project Developers. See the top-level COPYRIGHT file for details.
 *
 * SPDX-License-Identifier: (BSD-3-Clause)
 */

#ifndef AXOM_COMMON_CONFIG_HPP
#define AXOM_COMMON_CONFIG_HPP

/*
 * Note: Use only C-style comments in this file
 *       since it might be included from a C file
 */


/*
 * Axom Version Information
 */
#define AXOM_VERSION_MAJOR 0
#define AXOM_VERSION_MINOR 4
#define AXOM_VERSION_PATCH 0
#define AXOM_VERSION_FULL  "v0.4.0"
/* #undef AXOM_VERSION_EXTRA */


/*
 * Axom source location
 */
#define AXOM_SRC_DIR "/construction/science/axom/axom-0.4.0/src"
#define AXOM_BIN_DIR "/construction/science/axom/.build"
#define AXOM_DATA_DIR "/construction/science/axom/axom-0.4.0/data"

/*
 * Indicates whether Axom is compiled with Annotations that can facilitate
 * evaluation of performance with various performance tools.
 */
/* #undef AXOM_USE_ANNOTATIONS */

/*
 * Platform specific definitions
 */
#define AXOM_CXX_STD "c++11"
/* #undef AXOM_CUDA_ARCH */
/* #undef AXOM_NO_INT64_T */
/* #undef AXOM_USE_MPI3 */

#ifndef AXOM_NO_INT64_T
/* #undef AXOM_USE_64BIT_INDEXTYPE */
#endif


/*
 * Compiler tests
 */
/* #undef USE_C_LOC_WITH_ASSUMED_SHAPE */


/*
 * Compiler defines for libraries (built-in and third party)
 */
#define AXOM_USE_CLI11
#define AXOM_USE_CONDUIT
/* #undef AXOM_USE_CUDA */
#define AXOM_USE_FMT
/* #undef AXOM_USE_HDF5 */
/* #undef AXOM_USE_LUA */
/* #undef AXOM_USE_MFEM */
/* #undef AXOM_USE_MPI */
/* #undef AXOM_USE_MPIF_HEADER */
/* #undef AXOM_USE_OPENMP */
/* #undef AXOM_USE_RAJA */
/* #undef AXOM_USE_SCR */
/* #undef AXOM_USE_SOL */
#define AXOM_USE_SPARSEHASH
/* #undef AXOM_USE_UMPIRE */


/*
 * We need to explicitly add some definitions on Windows
 * for math defines (_USE_MATH_DEFINES), and to disambiguate
 * Windows GDI geometry classes (NOGDI).
 */
#ifdef WIN32
#define _USE_MATH_DEFINES
#define NOGDI
#endif


/*
 * Compiler defines for Axom components
 */
#define AXOM_USE_INLET
#define AXOM_USE_MINT
/* #undef AXOM_USE_LUMBERJACK */
#define AXOM_USE_PRIMAL
#define AXOM_USE_QUEST
#define AXOM_USE_SIDRE
#define AXOM_USE_SLAM
#define AXOM_USE_SLIC
#define AXOM_USE_SPIN


/*
 * Compiler defines to configure the built-in fmt library
 */
#define FMT_EXCEPTIONS 0
#define FMT_HEADER_ONLY 1

/*
 * Compiler defines to configure the built-in sparsehash library
 */
#define SPARSEHASH_HASHFUN_HEADER <functional>
#define SPARSEHASH_HASHFUN_NAMESPACE std

#endif  /* AXOM_COMMON_CONFIG_CPP */

