# Copyright (c) 2017-2020, Lawrence Livermore National Security, LLC and
# other Axom Project Developers. See the top-level COPYRIGHT file for details.
#
# SPDX-License-Identifier: (BSD-3-Clause)
#------------------------------------------------------------------------------

cmake_minimum_required(VERSION 3.0 FATAL_ERROR)


####### Expanded from @PACKAGE_INIT@ by configure_package_config_file() #######
####### Any changes to this file will be overwritten by the next CMake run ####
####### The input file was axom-config.cmake.in                            ########

get_filename_component(PACKAGE_PREFIX_DIR "${CMAKE_CURRENT_LIST_DIR}/../" ABSOLUTE)

macro(set_and_check _var _file)
  set(${_var} "${_file}")
  if(NOT EXISTS "${_file}")
    message(FATAL_ERROR "File or directory ${_file} referenced by variable ${_var} does not exist !")
  endif()
endmacro()

macro(check_required_components _NAME)
  foreach(comp ${${_NAME}_FIND_COMPONENTS})
    if(NOT ${_NAME}_${comp}_FOUND)
      if(${_NAME}_FIND_REQUIRED_${comp})
        set(${_NAME}_FOUND FALSE)
      endif()
    endif()
  endforeach()
endmacro()

####################################################################################

if(NOT AXOM_FOUND)

  #----------------------------------------------------------------------------
  # Set version and paths
  #----------------------------------------------------------------------------
  
  set(AXOM_VERSION       "v0.4.0")
  set(AXOM_VERSION_MAJOR "0")
  set(AXOM_VERSION_MINOR "4")
  set(AXOM_VERSION_PATCH "0")
  
  set(AXOM_INSTALL_PREFIX "/usr/local")
  set(AXOM_INCLUDE_DIRS "${AXOM_INSTALL_PREFIX}/include")

  #----------------------------------------------------------------------------
  # Set user configuration options and features
  #----------------------------------------------------------------------------

  # Language features
  set(AXOM_ENABLE_FORTRAN     "OFF")
  set(AXOM_USE_CUDA           "")
  set(AXOM_USE_MPI            "")
  set(AXOM_USE_OPENMP         "")

  # Axom components
  set(AXOM_ENABLE_INLET       "ON")
  set(AXOM_ENABLE_LUMBERJACK  "OFF")
  set(AXOM_ENABLE_MINT        "ON")
  set(AXOM_ENABLE_PRIMAL      "ON")
  set(AXOM_ENABLE_QUEST       "ON")
  set(AXOM_ENABLE_SIDRE       "ON")
  set(AXOM_ENABLE_SLAM        "ON")
  set(AXOM_ENABLE_SLIC        "ON")
  set(AXOM_ENABLE_SPIN        "ON")

  # Axom built-in TPLs
  set(AXOM_USE_CLI11          "TRUE")
  set(AXOM_USE_FMT            "TRUE")
  set(AXOM_USE_SOL            "")
  set(AXOM_USE_SPARSEHASH     "TRUE")

  # Axom external TPLs
  set(AXOM_USE_CONDUIT        "TRUE")
  set(AXOM_USE_HDF5           "")
  set(AXOM_USE_LUA            "")
  set(AXOM_USE_MFEM           "")
  set(AXOM_USE_RAJA           "")
  set(AXOM_USE_SCR            "")
  set(AXOM_USE_UMPIRE         "")

  #----------------------------------------------------------------------------
  # Bring in required  dependencies for this axom configuration
  #----------------------------------------------------------------------------
  include(CMakeFindDependencyMacro)

  # conduit
  if(AXOM_USE_CONDUIT)
    set(AXOM_CONDUIT_DIR  "/usr/local")
    if(NOT CONDUIT_DIR) 
      set(CONDUIT_DIR ${AXOM_CONDUIT_DIR}) 
    endif()
    find_dependency(Conduit REQUIRED NO_DEFAULT_PATH PATHS "${CONDUIT_DIR}/lib/cmake")
  endif()

  # hdf5
  if(AXOM_USE_HDF5)
    set(AXOM_HDF5_DIR     "")
    # Note: Targets not currently imported
  endif()

  # lua
  if(AXOM_USE_LUA)
    set(AXOM_LUA_DIR     "")
    # Note: Targets not currently imported
  endif()

  # mfem
  if(AXOM_USE_MFEM)
    set(AXOM_MFEM_DIR     "")
    # Note: Targets not currently imported
  endif()

  # raja
  if(AXOM_USE_RAJA)
    set(AXOM_RAJA_DIR     "")
    if(NOT RAJA_DIR) 
      set(RAJA_DIR ${AXOM_RAJA_DIR}) 
    endif()
    find_dependency(RAJA REQUIRED NO_DEFAULT_PATH PATHS "${RAJA_DIR}/share/raja/cmake")
  endif()

  # scr
  if(AXOM_USE_SCR)
    set(AXOM_SCR_DIR      "")
    # Note: Targets not currently imported
  endif()

  # umpire
  if(AXOM_USE_UMPIRE)
    set(AXOM_UMPIRE_DIR   "")
    if(NOT UMPIRE_DIR) 
      set(UMPIRE_DIR ${AXOM_UMPIRE_DIR}) 
    endif()
    find_dependency(umpire REQUIRED NO_DEFAULT_PATH PATHS "${UMPIRE_DIR}/share/umpire/cmake")
  endif()

  #----------------------------------------------------------------------------
  # Include targets exported by cmake
  #----------------------------------------------------------------------------
  get_filename_component(AXOM_CMAKE_CONFIG_DIR "${CMAKE_CURRENT_LIST_FILE}" PATH)
  include(${AXOM_CMAKE_CONFIG_DIR}/axom-targets.cmake)

  # HACK: Clear INTERFACE_COMPILE_OPTIONS to avoid requiring OpenMP in user code
  # This can (hopefully) be removed when we fix axom/blt's treatment of OpenMP
  if(AXOM_USE_OPENMP)
    set(_fix_tgts axom)
    if(AXOM_USE_RAJA)
      list(APPEND _fix_tgts RAJA)
    endif()
    set_target_properties(${_fix_tgts} PROPERTIES INTERFACE_COMPILE_OPTIONS "")
    unset(_fix_tgts)
  endif()

  #----------------------------------------------------------------------------
  # Indicate that axom is correctly set up
  #----------------------------------------------------------------------------
  set(AXOM_FOUND TRUE)

endif()

